<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ExProcess</name>
    <message>
        <source>&amp;Run process</source>
        <translation type="vanished">&amp;Запустить процесс</translation>
    </message>
    <message>
        <location filename="../ExProcess.js" line="+81"/>
        <source>&amp;Run Process</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
